@@ -19,7 +19,7 @@ use strict;
 use warnings;
 
 use HTML::Mason;
-use HTML::Mason::Exceptions; 
+use HTML::Mason::Exceptions;
 use CGI;
 use EBox::Gettext;
 use EBox;
@@ -83,7 +83,7 @@ sub _title
 {
 	my $self = shift;
 
-	my $title = $self->{title}; 
+	my $title = $self->{title};
 	defined $title or $title = '';
 
 	my $filename = EBox::Config::templates . '/title.mas';
@@ -148,7 +148,7 @@ MASON_INTERP: {
   sub _masonInterp
     {
       my ($self) = @_;
-     
+
       return $masonInterp if defined $masonInterp;
 
       $masonInterp = HTML::Mason::Interp->new(
@@ -171,7 +171,7 @@ sub _print
 	$self->_header;
 	$self->_top;
 	$self->_menu;
-	print "</div><div id='limewrap'><div id='content'>";
+	print '<div id="limewrap"><div id="content">';
 	$self->_title;
 	$self->_error;
 	$self->_msg;
@@ -211,7 +211,7 @@ sub _loggedIn
 	return 1;
 }
 
-sub _urlToChain # (url) 
+sub _urlToChain # (url)
 {
 	my $str = shift;
 	$str =~ s/\?.*//g;
@@ -224,7 +224,7 @@ sub _urlToChain # (url)
 # arguments
 # 	- name of the required parameter
 # 	- display name for the parameter (as seen by the user)
-sub _requireParam # (param, display) 
+sub _requireParam # (param, display)
 {
 	my ($self, $param, $display) = @_;
 
@@ -236,14 +236,14 @@ sub _requireParam # (param, display)
 # arguments
 # 	- name of the required parameter
 # 	- display name for the parameter (as seen by the user)
-sub _requireParamAllowEmpty # (param, display) 
+sub _requireParamAllowEmpty # (param, display)
 {
 	my ($self, $param, $display) = @_;
 
         foreach my $cgiparam (@{$self->params}){
                 return if ($cgiparam =~ /^$param$/);
         }
-       
+
         throw EBox::Exceptions::DataMissing(data => $display);
 
 }
@@ -255,24 +255,28 @@ sub run
 	if (not $self->_loggedIn) {
 		$self->{redirect} = "/ebox/Login/Index";
 	}
-	else { 
+	else {
 	  try {
 	    settextdomain($self->domain());
 	    $self->_process();
-	  } 
+	  }
+	  catch EBox::Exceptions::Internal with {
+	    my $e = shift;
+	    throw $e;
+	  }
 	  catch EBox::Exceptions::Base with {
 	    my $e = shift;
 	    $self->setErrorFromException($e);
 	    if (defined($self->{redirect})) {
 	      $self->{chain} = $self->{redirect};
 	    }
-	  } 
+	  }
 	  otherwise {
 	    my $e = shift;
-	    $self->setErrorFromException($e);	 
-	  }
+        throw $e;
+	  };
 	}
-	
+
 	if (defined($self->{error})) {
 		#only keep the parameters in paramsKept
 		my $params = $self->params;
@@ -301,20 +305,20 @@ sub run
 		  $chain->run;
 		  return;
 		}
-	} 
+	}
 
 	if ((defined($self->{redirect})) && (!defined($self->{error}))) {
 		my $request = Apache2::RequestUtil->request();
 		my $headers = $request->headers_in();
-		my $via = $headers->{'Via'}; 
+		my $via = $headers->{'Via'};
 		my $host= $headers->{'Host'};
-		my $fwhost = $headers->{'X-Forwaded-Host'};
-		# If the connection comes from a Proxy, 
+		my $fwhost = $headers->{'X-Forwarded-Host'};
+		# If the connection comes from a Proxy,
 		# redirects with the Proxy IP address
 		if (defined($via) and defined($fwhost)) {
-			$host = $fwhost; 
+			$host = $fwhost;
 		}
-		my $protocol; 
+		my $protocol;
 		if ($request->subprocess_env('https')) {
 			$protocol = 'https';
 		} else {
@@ -323,26 +327,24 @@ sub run
 		my $url = "$protocol://${host}/ebox/" . $self->{redirect};
 		print($self->cgi()->redirect($url));
 		return;
-	} 
+	}
 
-	
 
-	try  { 
+	try  {
 	  settextdomain('ebox');
-	  $self->_print 
+	  $self->_print
 	} catch EBox::Exceptions::Internal with {
-	  my $error = __("An internal error has ocurred. " . 
-			 "This is most probably a bug, relevant ". 
-			 "information can be found in the logs.");
-	  $self->_print_error($error);
-	} 
+	  my $ex = shift;
+	  $self->setErrorFromException($ex);
+	  $self->_print_error($self->{error});
+	}
 	otherwise {
 	    my $ex = shift;
 	    my $logger = EBox::logger;
 	    if (isa_mason_exception($ex)) {
 	      $logger->error($ex->as_text);
 	      my $error = __("An internal error related to ".
-			     "a template has occurred. This is ". 
+			     "a template has occurred. This is ".
 			     "a bug, relevant information can ".
 			     "be found in the logs.");
 	      $self->_print_error($error);
@@ -350,7 +352,7 @@ sub run
 	      if ($ex->can('text')) {
 		$logger->error('Exception: ' . $ex->text());
 	      } else {
-		$logger->error("Unknown exception");			    
+		$logger->error("Unknown exception");
 	      }
 
 	      throw $ex;
@@ -359,11 +361,26 @@ sub run
 
 }
 
-
-
-
-
-sub unsafeParam # (param) 
+# Method: unsafeParam
+#
+#     Get the CGI parameter value in an unsafe way allowing all
+#     character
+#
+#     This is a security risk and it must be used with caution
+#
+# Parameters:
+#
+#     param - String the parameter's name to get the value from
+#
+# Returns:
+#
+#     string - the parameter's value without any security check if the
+#     context is scalar
+#
+#     array - containing the string values for the given parameter if
+#     the context is an array
+#
+sub unsafeParam # (param)
 {
 	my ($self, $param) = @_;
 	my $cgi = $self->cgi;
@@ -390,7 +407,7 @@ sub unsafeParam # (param)
 	}
 }
 
-sub param # (param) 
+sub param # (param)
 {
 	my ($self, $param) = @_;
 	my $cgi = $self->cgi;
@@ -494,33 +511,16 @@ sub _process
 {
     my ($self) = @_;
 
-    try {
 	$self->_validateParams();
 	$self->actuate();
-    }
-    otherwise {
-	my $e = shift;
-	$self->setErrorFromException($e);
-
-    };
-
-  try {
       $self->{params} = $self->masonParameters();
-    }
-    otherwise {
-      my $e = shift;
-      
-      EBox::error("Error in masonParameters");
-      $self->setErrorFromException($e) if !exists $self->{error};
-
-    };
 }
 
 # Method: setMsg
 #   sets the message attribute
 #
 # Parameters:
-#   $msg - message to be setted 
+#   $msg - message to be setted
 sub setMsg
 {
     my ($self, $msg) = @_;
@@ -528,10 +528,10 @@ sub setMsg
 }
 
 # Method: setError
-#   set the error message 
+#   set the error message
 #
 # Parameters:
-#   $error - message to be setted 
+#   $error - message to be setted
 sub setError
 {
   my ($self, $error) = @_;
@@ -555,19 +555,19 @@ sub setErrorFromException
       $self->{error} .= Dumper($ex);
       $self->{error} .= '</pre>\n';
       $self->{error} .= '<br/>\n';
-    } 
+    }
     elsif ($ex->isa('EBox::Exceptions::External')) {
       $self->{error} = $ex->stringify();
     }
     elsif ($ex->isa('EBox::Exceptions::Internal')) {
       $self->{error} = __("An internal error has ".
-			  "ocurred. This is most probably a ".
+			  "occurred. This is most probably a ".
 			  "bug, relevant information can be ".
 			  "found in the logs.");
     }
     elsif ($ex->isa('EBox::Exceptions::Base')) {
       $self->{error} = __("An unexpected internal ".
-			  "error has ocurred. This is a bug, ".
+			  "error has occurred. This is a bug, ".
 			  "relevant information can be found ".
 			  "in the logs.");
     }
@@ -628,10 +628,10 @@ sub setErrorchain
 }
 
 # Method: paramsAsHash
-#  		
-# Returns:
-#    a reference to a hash wich contains the CGI parameters and his values as keys and values of the hash	
-# 
+#
+# Returns: a reference to a hash which contains the CGI parameters and
+#    its values as keys and values of the hash
+#
 # Possible implentation improvements:
 #  maybe it will be good idea cache this in some field of the instance
 sub paramsAsHash
@@ -639,10 +639,10 @@ sub paramsAsHash
     my ($self) = @_;
 
     my @names = @{ $self->params() };
-    my %params = map { 
+    my %params = map {
       my $value = $self->param($_) ;
       $_ => $value
-    } @names; 
+    } @names;
 
     return \%params;
 }
@@ -655,7 +655,7 @@ sub _validateParams
     my $params_r    = $self->params();
     $params_r       = $self->_validateRequiredParams($params_r);
     $params_r       = $self->_validateOptionalParams($params_r);
-    
+
     my @paramsLeft = @{ $params_r };
     if (@paramsLeft ) {
       EBox::error("Unallowed parameters found in CGI request: @paramsLeft");
@@ -690,7 +690,7 @@ sub _validateOptionalParams
     my ($self, $params_r) = @_;
 
     my $matchResult_r = _matchParams($self->optionalParameters(), $params_r);
-    
+
     my $allMatches = all  @{ $matchResult_r->{matches} };
     my @newParams = grep { $_ ne $allMatches } @{ $params_r} ;
     return \@newParams;
@@ -757,17 +757,19 @@ sub requiredParameters
 
 
 # Method:  actuate
-#  		
+#
 #  This method is the workhouse of the CGI it must be overriden by the different CGIs to achieve their objectives
 sub actuate
 {}
 
 # Method: masonParameters
-#   This method must be overriden by the different child to return the adequate template parameter for his state. 
+#
+#    This method must be overriden by the different child to return
+#    the adequate template parameter for its state.
 #
 # Returns:
 #  a  reference to a list which contains the names and values of the different mason parameters
-# 
+#
 sub masonParameters
 {
   my ($self) = @_;
@@ -871,7 +873,7 @@ sub upload
 # 	the namespace used will be the one the base cgi belongs to.
 #
 # Parameters:
-# 
+#
 # 	(POSITIONAL)
 # 	namespace - string represeting the namespace in URL format. Example:
 # 			"EBox/Network"
@@ -879,7 +881,7 @@ sub upload
 sub setMenuNamespace
 {
 	my ($self, $namespace) = @_;
-	
+
 	$self->{'menuNamespace'} = $namespace;
 
 }
@@ -901,7 +903,7 @@ sub setMenuNamespace
 sub menuNamespace
 {
 	my ($self) = @_;
-	
+
 	if (exists $self->{'menuNamespace'}) {
 		return $self->{'menuNamespace'};
 	} else {
