@@ -36,7 +36,7 @@ my $old_domain;
 
 # Method: settextdomain
 #
-#	Sets the curent message domain   
+#	Sets the curent message domain
 #
 # Parameters:
 #
@@ -53,13 +53,13 @@ sub settextdomain # (domain)
 }
 
 #
-# Method: gettextdomain 
+# Method: gettextdomain
 #
-# 	Gathers  the curent message domain   
+# 	Gathers  the curent message domain
 #
 # Returns:
 #
-#      The current message domain 
+#      The current message domain
 #
 sub gettextdomain
 {
@@ -110,16 +110,16 @@ sub __expand # (translation, %arguments)
 }
 
 # Method: _set_packagedomain
-# 
+#
 # 	Fetch and set the module's domain.
 # 	Tries to call $PACKAGE::domain function
 # 	to fetch the domain
-# 	
+#
 sub _set_packagedomain
 {
 	my ($package, $filename, $line) = caller 1;
 	my $domain = undef;
-	eval {$domain = $package->domain};
+	eval {$domain = $package->domain()};
 	if ($domain) {
 		$old_domain = settextdomain($domain);
 	} else {
@@ -140,32 +140,36 @@ sub _unset_packagedomain
 
 my $langs;
 $langs->{'an_ES.UTF-8'} = 'Aragonés';
+$langs->{'bg_BG.UTF-8'} = 'Български';
 $langs->{'es_ES.UTF-8'} = 'Castellano';
 $langs->{'ca_ES.UTF-8'} = 'Català';
 $langs->{'da_DK.UTF-8'} = 'Dansk';
 $langs->{'de_DE.UTF-8'} = 'Deutsch';
 $langs->{'C'} = 'English';
 $langs->{'eu_ES.UTF-8'} = 'Euskara';
+$langs->{'fa_IR.UTF-8'} = 'فارسی';
 $langs->{'fr_FR.UTF-8'} = 'Français';
+$langs->{'gl_ES.UTF-8'} = 'Galego';
 $langs->{'it_IT.UTF-8'} = 'Italiano';
 $langs->{'ja_JP.UTF-8'} = '日本語';
+$langs->{'nb_NO.UTF-8'} = 'Norsk (bokmål)';
 $langs->{'nl_BE.UTF-8'} = 'Nederlands';
 $langs->{'pl_PL.UTF-8'} = 'Polski';
 $langs->{'pt_BR.UTF-8'} = 'Português do Brasil';
 $langs->{'pt_PT.UTF-8'} = 'Português';
-$langs->{'bg_BG.UTF-8'} = 'Български';
 $langs->{'ru_RU.UTF-8'} = 'Русский';
 $langs->{'sv_SE.UTF-8'} = 'Svenska';
 $langs->{'tr_TR.UTF-8'} = 'Türkçe';
+$langs->{'zh_TW.UTF-8'} = '繁體中文';
 
 # Method:  langname
 #
 #   	Gathers the current set language
 #
 # Returns:
-#	
+#
 #	the current domain language
-#       
+#
 sub langname # (locale)
 {
 	my ($locale) = @_;
@@ -174,14 +178,14 @@ sub langname # (locale)
 }
 
 # Method: langs
-#  	gathers the available languages 
+#  	gathers the available languages
 #
 # Returns:
 #
-#	hash reference -  containing the available languages. Each key 
-#	represents a *locale* and its value contains the associated 
-#	language	 
-#		
+#	hash reference -  containing the available languages. Each key
+#	represents a *locale* and its value contains the associated
+#	language
+#
 sub langs
 {
 	return $langs;
